{*******************************************************************}
{                                                                   }
{  ZMouse.pas, Copyright (c) Simon Page 1998                        }
{                                                                   }
{  Version....: 1.01                                                }
{                                                                   }
{  Purpose....: Pascal conversion & extension of ZMouse.h           }
{                                                                   }
{  Requires...: Delphi 2 or greater                                 }
{                                                                   }
{*******************************************************************}

{$I WheelMs.inc}

unit ZMouse;

interface

uses Windows, Messages;

{$IFDEF VERSION3_DOWN}
const

  MSH_MOUSEWHEEL = 'MSWHEEL_ROLLMSG';

  MOUSEZ_CLASSNAME      = 'MouseZ';             // wheel window class
  MOUSEZ_TITLE          = 'Magellan MSWHEEL';   // wheel window title

  MSH_WHEELMODULE_CLASS = MOUSEZ_CLASSNAME;
  MSH_WHEELMODULE_TITLE = MOUSEZ_TITLE;

  MSH_WHEELSUPPORT = 'MSH_WHEELSUPPORT_MSG';    // name of msg to send
                                                // to query for wheel support
  { MSH_WHEELSUPPORT
    wParam - not used
    lParam - not used
    returns BOOL - TRUE if wheel support is active, FALSE otherwise }

  MSH_SCROLL_LINES = 'MSH_SCROLL_LINES_MSG';

  { MSH_SCROLL_LINES
    wParam - not used
    lParam - not used
    returns int  - number of lines to scroll on a wheel roll }

    { For Win95 and WinNT3.51,  Mswheel broadcasts the message
    WM_SETTINGCHANGE (equivalent to WM_WININICHANGE) when the scroll
    lines has changed.  Applications will recieve the WM_SETTINGCHANGE
    message with the wParam set to SPI_SETWHEELSCROLLLINES.  When
    this message is received the application should query Mswheel
    for the new setting.}

{$ENDIF}

{$IFDEF VERSION2_DOWN}
  { Define extra constants not present in Delphi <= 2.x}

  WHEEL_PAGESCROLL        = MAXDWORD;           // Scroll one page indicator value
  SPI_GETWHEELSCROLLLINES = 104;                // SystemParametersInfo value
  WHEEL_DELTA             = 120;                // Default value for rolling one notch
  WM_MOUSEWHEEL           = (WM_MOUSELAST + 1); // message that will be supported by the OS
{$ENDIF}


  function GetMSWheelHWnd(var Msh_MsgMouseWheel: Integer;
                     var Msh_Msg3DSupport: Integer;
                     var Msh_MsgScrollLines: Integer;
                     var Support3D: Boolean;
                     var ScrollLines: Integer): HWnd;

  function OSNativeWheelSupport: Boolean;

  procedure UpdateWheelMouseInfo;

var
  MsWheelNativeSupp: Boolean;
  MsWheelAltSupp: Boolean;
  MsWheelWnd: HWnd;
  Msh_MsgWheelMove,
  Msh_MsgQuery3DSupp,
  Msh_MsgQueryLines: Integer;
  MsWheelScrollLines: Integer;
  MsWheelSupport3D: Boolean;

implementation


function GetMSWheelHWnd(var Msh_MsgMouseWheel: Integer;
                     var Msh_Msg3DSupport: Integer;
                     var Msh_MsgScrollLines: Integer;
                     var Support3d: Boolean;
                     var ScrollLines: Integer): HWnd;
begin
   Result := FindWindow(MSH_WHEELMODULE_CLASS, MSH_WHEELMODULE_TITLE);
   if Result = 0 then // support not found
   begin
     Msh_MsgMouseWheel := 0;
     Msh_Msg3DSupport := 0;
     Msh_MsgScrollLines := 0;
     Support3D := False;
     ScrollLines := 0;
     Exit;
   end;
   Msh_MsgMouseWheel := RegisterWindowMessage(MSH_MOUSEWHEEL);
   Msh_Msg3DSupport := RegisterWindowMessage(MSH_WHEELSUPPORT);
   Msh_MsgScrollLines := RegisterWindowMessage(MSH_SCROLL_LINES);
   if (Msh_Msg3DSupport <> 0) then
      Support3d := BOOL(SendMessage(Result, Msh_Msg3DSupport, 0, 0))
   else Support3d := FALSE;  // default to FALSE
   if (Msh_MsgScrollLines <> 0) then
      ScrollLines := SendMessage(Result, Msh_MsgScrollLines, 0, 0)
   else ScrollLines := 3;  // default
end;

function OSNativeWheelSupport: Boolean;
var
  DummyLines: Integer;
begin
  Result := SystemParametersInfo(SPI_GETWHEELSCROLLLINES, 0, @DummyLines, 0);
end;

procedure UpdateWheelMouseInfo;
begin
  MsWheelNativeSupp := OSNativeWheelSupport;
  { call function even if native support as this clears the values }
  MsWheelWnd := GetMSWheelHWnd(Msh_MsgWheelMove, Msh_MsgQuery3DSupp,
               Msh_MsgQueryLines, MsWheelSupport3d, MsWheelScrollLines);
  { if there is native support get the actual setting }
  if MsWheelNativeSupp then
    SystemParametersInfo(SPI_GETWHEELSCROLLLINES, 0, @MsWheelScrollLines, 0);
  MsWheelAltSupp := MsWheelWnd <> 0;
end;


initialization
  UpdateWheelMouseInfo;
end.



